@@ -88,26 +88,26 @@ class Certificate(model.BaseObject):
 
     @property
     def title(self):
-        return self.json_data.get("title", u"")
+        return self.json_data.get("title", "")
 
     @property
     def hr_date(self):
-        date = self.json_data.get("date", u"").split("-")
+        date = self.json_data.get("date", "").split("-")
         if not date:
-            return u""
+            return ""
         try:
             date[1] = api.portal.translate(
                 monthname_msgid(date[1]), domain="plonelocales"
             )
         except Exception:
             logger.error("Not a valid date %r", date)
-        return u" ".join(reversed(date))
+        return " ".join(reversed(date))
 
     @property
     def hr_date_plain(self):
-        date = self.json_data.get("date", u"")
+        date = self.json_data.get("date", "")
         if not date:
-            return u""
+            return ""
         return datetime.strptime(date, "%Y-%m-%d")
 
 
@@ -153,7 +153,7 @@ MODULE_WITH_UNANSWERED_RISKS_FILTER = sql.and_(
                 node.session_id == model.SurveyTreeItem.session_id,
                 node.id == model.Risk.sql_risk_id,
                 node.type == "risk",
-                model.Risk.identification == None,
+                model.Risk.identification == None,  # noqa: E711
                 node.depth > model.SurveyTreeItem.depth,
                 node.path.like(model.SurveyTreeItem.path + "%"),
             )
